'use strict';

var view = require('@codemirror/view');
var language = require('@codemirror/language');
var highlight = require('@lezer/highlight');

// Volcano theme color definitions aligned with the schema
const base00 = '#390000', // Background
base01 = '#F8F8F8', // Foreground
base02 = '#750000', // Selection and Selection Match
base03 = '#e7c0c0ff', // Comment
base04 = '#970000', // Cursor
base05 = '#f12727ff', // Keyword
base06 = '#edef7dff', // Variable, Parameter, String, Regexp
base07 = '#ffb454ff', // Function
base08 = '#ec0d1e', // Constant
base09 = '#9df39fff', // Type
base0A = '#fec758ff', // Class, Heading
base0B = '#994646ff', // Number
base0C = '#aa5507ff', // Tag
invalid = '#ffffffff'; // Invalid
const darkBackground = '#580000', // Dropdown background
highlightBackground = '#ff000033', // Active line and Matching bracket
tooltipBackground = base01, // Tooltip using foreground color
cursor = base04, // Caret color
selection = base02; // Selection color
// Define the editor theme styles for Volcano.
const volcanoTheme = view.EditorView.theme({
    '&': {
        color: base01,
        backgroundColor: base00,
    },
    '.cm-content': {
        caretColor: cursor,
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: cursor,
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection,
    },
    '.cm-searchMatch': {
        backgroundColor: base02, // Use the selection color for search matches
        color: base01, // Foreground color for text
        outline: `1px solid ${base03}`, // Outline using comment color
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: base05, // Use the keyword color for the selected search match
        color: base00, // Background color for high visibility
    },
    '.cm-panels': {
        backgroundColor: darkBackground,
        color: base01,
    },
    '.cm-panels.cm-panels-top': {
        borderBottom: '2px solid black',
    },
    '.cm-panels.cm-panels-bottom': {
        borderTop: '2px solid black',
    },
    '.cm-activeLine': {
        backgroundColor: highlightBackground,
    },
    '.cm-gutters': {
        backgroundColor: darkBackground,
        color: base03,
    },
    '.cm-tooltip': {
        backgroundColor: tooltipBackground,
    },
}, { dark: true });
// Define the highlighting style for code in the Volcano theme.
const volcanoHighlightStyle = language.HighlightStyle.define([
    { tag: highlight.tags.keyword, color: base05 },
    { tag: [highlight.tags.name, highlight.tags.deleted, highlight.tags.character, highlight.tags.macroName], color: base06 },
    { tag: [highlight.tags.propertyName], color: base07 },
    { tag: [highlight.tags.processingInstruction, highlight.tags.string, highlight.tags.inserted, highlight.tags.special(highlight.tags.string)], color: base06 },
    { tag: [highlight.tags.function(highlight.tags.variableName), highlight.tags.labelName], color: base07 },
    { tag: [highlight.tags.color, highlight.tags.constant(highlight.tags.name), highlight.tags.standard(highlight.tags.name)], color: base08 },
    { tag: [highlight.tags.definition(highlight.tags.name), highlight.tags.separator], color: base06 },
    { tag: [highlight.tags.className], color: base0A },
    { tag: [highlight.tags.number, highlight.tags.changed, highlight.tags.annotation, highlight.tags.modifier, highlight.tags.self, highlight.tags.namespace], color: base0B },
    { tag: [highlight.tags.typeName], color: base09 },
    { tag: [highlight.tags.operator, highlight.tags.operatorKeyword], color: base05 },
    { tag: [highlight.tags.url, highlight.tags.escape, highlight.tags.regexp, highlight.tags.link], color: base06 },
    { tag: [highlight.tags.meta, highlight.tags.comment], color: base03 },
    { tag: highlight.tags.tagName, color: base0C },
    { tag: highlight.tags.strong, fontWeight: 'bold' },
    { tag: highlight.tags.emphasis, fontStyle: 'italic' },
    { tag: highlight.tags.link, textDecoration: 'underline' },
    { tag: highlight.tags.heading, fontWeight: 'bold', color: base0A },
    { tag: [highlight.tags.atom, highlight.tags.bool, highlight.tags.special(highlight.tags.variableName)], color: base06 },
    { tag: highlight.tags.invalid, color: invalid },
    { tag: highlight.tags.strikethrough, textDecoration: 'line-through' },
]);
// Extension to enable the Volcano theme (both the editor theme and the highlight style).
const volcano = [
    volcanoTheme,
    language.syntaxHighlighting(volcanoHighlightStyle),
];

exports.volcano = volcano;
exports.volcanoHighlightStyle = volcanoHighlightStyle;
exports.volcanoTheme = volcanoTheme;
