import { EditorView } from '@codemirror/view';
import { HighlightStyle, syntaxHighlighting } from '@codemirror/language';
import { tags } from '@lezer/highlight';

// Volcano theme color definitions aligned with the schema
const base00 = '#390000', // Background
base01 = '#F8F8F8', // Foreground
base02 = '#750000', // Selection and Selection Match
base03 = '#e7c0c0ff', // Comment
base04 = '#970000', // Cursor
base05 = '#f12727ff', // Keyword
base06 = '#edef7dff', // Variable, Parameter, String, Regexp
base07 = '#ffb454ff', // Function
base08 = '#ec0d1e', // Constant
base09 = '#9df39fff', // Type
base0A = '#fec758ff', // Class, Heading
base0B = '#994646ff', // Number
base0C = '#aa5507ff', // Tag
invalid = '#ffffffff'; // Invalid
const darkBackground = '#580000', // Dropdown background
highlightBackground = '#ff000033', // Active line and Matching bracket
tooltipBackground = base01, // Tooltip using foreground color
cursor = base04, // Caret color
selection = base02; // Selection color
// Define the editor theme styles for Volcano.
const volcanoTheme = /*@__PURE__*/EditorView.theme({
    '&': {
        color: base01,
        backgroundColor: base00,
    },
    '.cm-content': {
        caretColor: cursor,
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: cursor,
    },
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection,
    },
    '.cm-searchMatch': {
        backgroundColor: base02, // Use the selection color for search matches
        color: base01, // Foreground color for text
        outline: `1px solid ${base03}`, // Outline using comment color
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: base05, // Use the keyword color for the selected search match
        color: base00, // Background color for high visibility
    },
    '.cm-panels': {
        backgroundColor: darkBackground,
        color: base01,
    },
    '.cm-panels.cm-panels-top': {
        borderBottom: '2px solid black',
    },
    '.cm-panels.cm-panels-bottom': {
        borderTop: '2px solid black',
    },
    '.cm-activeLine': {
        backgroundColor: highlightBackground,
    },
    '.cm-gutters': {
        backgroundColor: darkBackground,
        color: base03,
    },
    '.cm-tooltip': {
        backgroundColor: tooltipBackground,
    },
}, { dark: true });
// Define the highlighting style for code in the Volcano theme.
const volcanoHighlightStyle = /*@__PURE__*/HighlightStyle.define([
    { tag: tags.keyword, color: base05 },
    { tag: [tags.name, tags.deleted, tags.character, tags.macroName], color: base06 },
    { tag: [tags.propertyName], color: base07 },
    { tag: [tags.processingInstruction, tags.string, tags.inserted, /*@__PURE__*/tags.special(tags.string)], color: base06 },
    { tag: [/*@__PURE__*/tags.function(tags.variableName), tags.labelName], color: base07 },
    { tag: [tags.color, /*@__PURE__*/tags.constant(tags.name), /*@__PURE__*/tags.standard(tags.name)], color: base08 },
    { tag: [/*@__PURE__*/tags.definition(tags.name), tags.separator], color: base06 },
    { tag: [tags.className], color: base0A },
    { tag: [tags.number, tags.changed, tags.annotation, tags.modifier, tags.self, tags.namespace], color: base0B },
    { tag: [tags.typeName], color: base09 },
    { tag: [tags.operator, tags.operatorKeyword], color: base05 },
    { tag: [tags.url, tags.escape, tags.regexp, tags.link], color: base06 },
    { tag: [tags.meta, tags.comment], color: base03 },
    { tag: tags.tagName, color: base0C },
    { tag: tags.strong, fontWeight: 'bold' },
    { tag: tags.emphasis, fontStyle: 'italic' },
    { tag: tags.link, textDecoration: 'underline' },
    { tag: tags.heading, fontWeight: 'bold', color: base0A },
    { tag: [tags.atom, tags.bool, /*@__PURE__*/tags.special(tags.variableName)], color: base06 },
    { tag: tags.invalid, color: invalid },
    { tag: tags.strikethrough, textDecoration: 'line-through' },
]);
// Extension to enable the Volcano theme (both the editor theme and the highlight style).
const volcano = [
    volcanoTheme,
    /*@__PURE__*/syntaxHighlighting(volcanoHighlightStyle),
];

export { volcano, volcanoHighlightStyle, volcanoTheme };
